Index: trunk/source/processes/electromagnetic/xrays/include/G4ForwardXrayTR.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4ForwardXrayTR.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4ForwardXrayTR.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4ForwardXrayTR.hh,v 1.14 2006/06/29 19:55:33 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // G4ForwardXrayTR -- header file
Index: trunk/source/processes/electromagnetic/xrays/include/G4GammaXTRadiator.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4GammaXTRadiator.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4GammaXTRadiator.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4GammaXTRadiator.hh,v 1.4 2006/06/29 19:55:35 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // 
Index: trunk/source/processes/electromagnetic/xrays/include/G4RegularXTRadiator.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4RegularXTRadiator.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4RegularXTRadiator.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4RegularXTRadiator.hh,v 1.3 2006/06/29 19:55:37 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // 
Index: trunk/source/processes/electromagnetic/xrays/include/G4Scintillation.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4Scintillation.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4Scintillation.hh	(revision 1196)
@@ -25,6 +25,6 @@
 //
 //
-// $Id: G4Scintillation.hh,v 1.15 2008/06/13 01:04:49 gum Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4Scintillation.hh,v 1.16 2009/07/29 23:45:20 gum Exp $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // 
@@ -119,5 +119,5 @@
         G4bool IsApplicable(const G4ParticleDefinition& aParticleType);
         // Returns true -> 'is applicable', for any particle type except
-        // for an 'opticalphoton' 
+        // for an 'opticalphoton' and for short-lived particles
 
 	G4double GetMeanFreePath(const G4Track& aTrack,
@@ -216,9 +216,8 @@
 G4bool G4Scintillation::IsApplicable(const G4ParticleDefinition& aParticleType)
 {
-        if (aParticleType.GetParticleName() == "opticalphoton"){
-           return false;
-        } else {
-           return true;
-        }
+       if (aParticleType.GetParticleName() == "opticalphoton") return false;
+       if (aParticleType.IsShortLived()) return false;
+
+       return true;
 }
 
Index: trunk/source/processes/electromagnetic/xrays/include/G4StrawTubeXTRadiator.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4StrawTubeXTRadiator.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4StrawTubeXTRadiator.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4StrawTubeXTRadiator.hh,v 1.4 2007/09/29 17:49:34 vnivanch Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // 
Index: trunk/source/processes/electromagnetic/xrays/include/G4SynchrotronRadiation.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4SynchrotronRadiation.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4SynchrotronRadiation.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4SynchrotronRadiation.hh,v 1.4 2006/06/29 19:55:43 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // ------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/xrays/include/G4SynchrotronRadiationInMat.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4SynchrotronRadiationInMat.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4SynchrotronRadiationInMat.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4SynchrotronRadiationInMat.hh,v 1.2 2006/06/29 19:55:45 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // ------------------------------------------------------------
Index: trunk/source/processes/electromagnetic/xrays/include/G4TransitionRadiation.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4TransitionRadiation.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4TransitionRadiation.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4TransitionRadiation.hh,v 1.9 2006/06/29 19:55:47 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // G4TransitionRadiation  -- header file
Index: trunk/source/processes/electromagnetic/xrays/include/G4TransparentRegXTRadiator.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4TransparentRegXTRadiator.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4TransparentRegXTRadiator.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4TransparentRegXTRadiator.hh,v 1.2 2006/06/29 19:55:49 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // 
Index: trunk/source/processes/electromagnetic/xrays/include/G4VTRModel.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4VTRModel.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4VTRModel.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VTRModel.hh,v 1.3 2006/06/29 19:55:51 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // G4VTRModel  -- header file
Index: trunk/source/processes/electromagnetic/xrays/include/G4VTransitionRadiation.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4VTransitionRadiation.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4VTransitionRadiation.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VTransitionRadiation.hh,v 1.3 2006/06/29 19:55:53 gunter Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // G4VTransitionRadiation  -- header file
Index: trunk/source/processes/electromagnetic/xrays/include/G4VXTRenergyLoss.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4VXTRenergyLoss.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4VXTRenergyLoss.hh	(revision 1196)
@@ -26,5 +26,5 @@
 //
 // $Id: G4VXTRenergyLoss.hh,v 1.24 2007/09/29 17:49:34 vnivanch Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // 

Index: trunk/source/processes/electromagnetic/xrays/include/G4Cerenkov.hh
===================================================================
--- trunk/source/processes/electromagnetic/xrays/include/G4Cerenkov.hh	(revision 1007)
+++ trunk/source/processes/electromagnetic/xrays/include/G4Cerenkov.hh	(revision 1196)
@@ -25,6 +25,6 @@
 //
 //
-// $Id: G4Cerenkov.hh,v 1.10 2008/10/22 01:17:36 gum Exp $
-// GEANT4 tag $Name: geant4-09-02 $
+// $Id: G4Cerenkov.hh,v 1.11 2009/07/29 23:45:02 gum Exp $
+// GEANT4 tag $Name: geant4-09-03-cand-01 $
 //
 // 
@@ -108,5 +108,6 @@
 
         G4bool IsApplicable(const G4ParticleDefinition& aParticleType);
         // Returns true -> 'is applicable', for all charged particles.
 
         G4double GetMeanFreePath(const G4Track& aTrack,
@@ -212,9 +213,8 @@
 G4bool G4Cerenkov::IsApplicable(const G4ParticleDefinition& aParticleType)
 {
-   if (aParticleType.GetParticleName() != "chargedgeantino" ) {
-      return (aParticleType.GetPDGCharge() != 0);
-   } else {
-      return false;
-   }
+   if (aParticleType.GetParticleName() == "chargedgeantino") return false;
+   if (aParticleType.IsShortLived()) return false;
+
+   return (aParticleType.GetPDGCharge() != 0);
 }
 
@@ -108,5 +108,6 @@
 
         G4bool IsApplicable(const G4ParticleDefinition& aParticleType);
-        // Returns true -> 'is applicable', for all charged particles.
+        // Returns true -> 'is applicable', for all charged particles
+        // except short-lived particles.
 
         G4double GetMeanFreePath(const G4Track& aTrack,